Class: Duxml::HistoryClass
Overview
as an object, HistoryClass holds events latest first, earliest last it also has delegators that allow the use of Array-style notation e.g. ‘[]’ and #each to search the history.
Instance Attribute Summary collapse
-
#nodes ⇒ Object
(also: #events)
readonly
Returns the value of attribute nodes.
Attributes included from Reportable
Attributes included from Duxml
Attributes included from Saxer
Instance Method Summary collapse
-
#initialize(strict_or_false = true) ⇒ HistoryClass
constructor
A new instance of HistoryClass.
Methods included from History
#description, #grammar, #inspect, #latest, #strict?, #update, #xml
Methods included from Reportable
Methods included from Duxml
Methods included from Saxer
Constructor Details
#initialize(strict_or_false = true) ⇒ HistoryClass
Returns a new instance of HistoryClass.
31 32 33 34 |
# File 'lib/duxml/meta/history.rb', line 31 def initialize(strict_or_false = true) @nodes = [] @strict = strict_or_false end |
Instance Attribute Details
#nodes ⇒ Object (readonly) Also known as: events
Returns the value of attribute nodes.
36 37 38 |
# File 'lib/duxml/meta/history.rb', line 36 def nodes @nodes end |