Class: Duxml::HistoryClass
Overview
as an object, HistoryClass holds events latest first, earliest last it also has delegators that allow the use of Array-style notation e.g. ‘[]’ and #each to search the history.
Constant Summary
Constants included from Duxml
Constants included from Meta
Instance Attribute Summary collapse
-
#nodes ⇒ Object
(also: #events)
readonly
Returns the value of attribute nodes.
Attributes included from Duxml
Attributes included from Saxer
Instance Method Summary collapse
-
#initialize(harsh_or_kind = true) ⇒ HistoryClass
constructor
A new instance of HistoryClass.
Methods included from History
#description, #grammar, #inspect, #latest, #strict?, #update, xml
Methods included from Reportable
Methods included from Duxml
#create, #load, #log, #relaxng, #save, #validate
Methods included from Meta
Methods included from Saxer
Constructor Details
#initialize(harsh_or_kind = true) ⇒ HistoryClass
Returns a new instance of HistoryClass.
31 32 33 34 |
# File 'lib/duxml/meta/history.rb', line 31 def initialize(harsh_or_kind = true) @nodes = [] @strict = harsh_or_kind end |
Instance Attribute Details
#nodes ⇒ Object (readonly) Also known as: events
Returns the value of attribute nodes.
36 37 38 |
# File 'lib/duxml/meta/history.rb', line 36 def nodes @nodes end |